<?php

namespace App\Service;

use App\Entity\User;
use App\Git\CustomGitRepository;

class SnipService
{
    private const SNIP_FILE_NAME = 'snip.txt';
    private const MASTER_BRANCH_NAME = 'master';

    public function __construct(
        private readonly CustomGitRepository $repo,
        private readonly User                $user,
    )
    {
    }

    private function snipExists(): bool
    {
        return file_exists($this->getSnipPath());
    }

    private function getSnipPath(): string
    {
        return sprintf('%s/snip.txt', $this->repo->getRepositoryPath());
    }

    public function update(string $snipContents): void
    {
        if ($this->repo->getCurrentBranchName() !== self::MASTER_BRANCH_NAME) {
            $this->repo->checkout(self::MASTER_BRANCH_NAME);
        }
        file_put_contents($this->getSnipPath(), $snipContents);
        $this->repo->addFile(self::SNIP_FILE_NAME);
        if ($this->repo->hasChanges()) {
            $this->repo->commit(sprintf('Updated snip at %s by %s', date('Y-m-d H:i:s'), $this->user));
        }
    }

    public function get(): string
    {
        if (!$this->snipExists()) {
            return '';
        }
        return file_get_contents($this->getSnipPath());
    }

    public function getRepo(): CustomGitRepository
    {
        return $this->repo;
    }
}